@@ -28,7 +28,7 @@ my $cmake_gen;
 GetOptions( 'gen=s' => \$cmake_gen, )
     or die 'Wrong options';
 
-local $ENV{RUN_TESTS_VERBOSE} = 1;
+local $ENV{RUN_TESTS_VERBOSE} = ( $ENV{RUN_TESTS_VERBOSE} // 1 );
 if ( defined $cmake_gen )
 {
     $ENV{CMAKE_GEN} = $cmake_gen;
